| Title: | Generalized Orthogonal GARCH (GO-GARCH) Models |
|---|---|
| Description: | Provision of classes and methods for estimating generalized orthogonal GARCH models. This is an alternative approach to CC-GARCH models in the context of multivariate volatility modeling. |
| Authors: | Bernhard Pfaff [aut, cre] |
| Maintainer: | Bernhard Pfaff <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.7-6 |
| Built: | 2026-05-24 07:36:01 UTC |
| Source: | https://github.com/cran/gogarch |
Levels of the Dow Jones Industrial Average and NASDAQ stock indices for the period 03/23/1990 until 03/23/2000.
data(BVDW)data(BVDW)
A data frame with 2610 observations on the following 3 variables.
DateDate in the format YYYYMMDD.
DJIALevel of the DIJA.
NASDAQLevel of the NASDAQ.
This data set has been utilized in the source below and was kindly provided by Roy van der Weide.
Boswijk, H. Peter and van der Weide, Roy (2006), Wake me up before you GO-GARCH, Tinbergen Institute Discussion Paper, TI 2006-079/4, University of Amsterdam and Tinbergen Institute.
data(BVDW) str(BVDW)data(BVDW) str(BVDW)
This data frame contains the stock prices from American Airlines, South-West Airlines, Boeing and FedEx. In addition the spot prices for crude oil and kerosene are included. This data set was used in the article by Boswijk and van der Weide (2009). The data range is from July, 19 1993 until August, 12 2008.
data(BVDWAIR)data(BVDWAIR)
A data frame with 3791 observations on the following 7 variables.
DatePOSIXt: The dates of observations.
CrudeOilCrude oil price.
KeroseneKerosene price.
AmericanAirStock prices of American Airlines.
SouthWestStock prices of South-West Airlines.
BoeingStock prices of Boeing.
FedExStock prices of Boeing.
The stock price data was downloaded from Yahoo Finance and the price series for crude oil and kerosene were obtained from the U.S. Energy Information Administration (EIA).
Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.
data(BVDWAIR) str(BVDWAIR)data(BVDWAIR) str(BVDWAIR)
The data frame contains the following sector indices of the EURO STOXX 600 index: Automobiles & Parts, Banks, Basic Resources, Chemicals, Construction and Materials, Financial Services, Food & Beverages, Health Care, Industrial Goods & Services, Insurance, Media, Oil & Gas, Technology, Telecommunications and Utilities. The data range is from 31th December 1986 until 21st November 2008.
data(BVDWSTOXX)data(BVDWSTOXX)
A data frame with 5652 observations on the following 16 variables.
DatePOSIXt: The dates of observations.
AutoPartsSector index Automobiles & Parts
BanksSector index Banks
BasicResSector index Basic Resources
ChemicalsSector index Chemicals
ConstrMatSector index Construction and Materials
FoodBeverageSector index Food & Beverages
FinServiceSector index Financial Services
HealthCareSector index Health Care
IndustrialGoodsSector index Industrial Goods & Services
InsuranceSector index Insurance
MediaSector index Media
OilGasSector index Oil & Gas
TechnologySector index Technology
TelecomSector index Telecommunications
UtilitiesSector index Utilities
Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.
data(BVDWSTOXX) str(BVDWSTOXX)data(BVDWSTOXX) str(BVDWSTOXX)
This function computes the autocorrelation matrix for a given lag. For instance, it is used for estimating GO-GARCH models whence the method of moments is utilized.
cora(SSI, lag = 1, standardize = TRUE)cora(SSI, lag = 1, standardize = TRUE)
SSI |
Array with dimension |
lag |
Integer, the lag for which the autocorrelation is computed. |
standardize |
Logical, if |
This function computes the autocorrelation matrix according to:
It is computationally assured that is symmetric
by setting it equal to: . The standardization matrix is derived from the singular value decomposition of the
co-variance matrix at lag zero.
cora |
Matrix with dimension |
Bernhard Pfaff
Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.
These are methods for estimating GO-GARCH models. Currently only a method for estimating GO-GARCH models by Maximum-Likelihood is implemented.
The declared estimation methods are called from function
gogarch.
signature(object = "Goestica")
signature(object = "Goestmm")
signature(object = "Goestml")
signature(object = "Goestnls")
Bernhard Pfaff
garchFit, Goestica,
Goestml, Goestnls,
Goestmm, gogarch
This class contains the GoGARCH class and has the mixing matrix
as additional slot.
Objects can be created by calls of the form new("Goestmm", ...),
or with the function gogarch whereby method = "ica" has
been set.
ica:Object of class "list": List object
returned by fastICA.
Z:Object of class "matrix": Transformation matrix.
U:Object of class "matrix": Orthogonal matrix.
Y:Object of class "matrix": Extracted
component matrix.
H:Object of class "list": List of conditional
variance/covariance matrices.
models:Object of class "list": List of
univariate GARCH model fits.
estby:Object of class "character": Estimation method.
X:Object of class "matrix": The data matrix.
V:Object of class "matrix": Covariance matrix
of X.
P:Object of class "matrix": Left singular
values of Var/Cov matrix of X.
Dsqr:Object of class "matrix": Square roots of
eigenvalues on diagonal, else zero.
garchf:Object of class "formula": Garch
formula used for uncorrelated component GARCH models.
name:Object of class "character": The name of
the original data object.
Class "GoGARCH", directly.
Class "Goinit", by class "GoGARCH", distance 2.
Returns the conditional variances as object with class attribute
"mts" "ts".
Returns the conditional co-variances as object with
class attribute "mts" "ts".
Returns the conditional correlationsas object with class
attribute "mts" "ts".
Returns the coeffiecients of the component GARCH models.
Returns the convergence codes of the component GARCH models.
Returns the formula for the component GARCH models.
Fast ICA estimation of Go-GARCH models.
Plotting of the conditional correlations.
Returns the conditional covariances and mean
forecasts and the forecasts of the component GARCH models, object is
of class Gopredict.
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
show-method for objects of class Goestmm.
summary-method for objects of class Goestml,
object is of class Gosum.
Updates an object of class Goestml.
Bernhard Pfaff
Broda, S.A. and Paolella, M.S. (2008): CHICAGO: A Fast and Accurate Method for Portfolio Risk Calculation, Swiss Finance Institute, Research Paper Series No. 08-08, Zuerich.
GoGARCH, Goinit,
Gosum, Gopredict,
goest-methods and gogarch
This class contains the GoGARCH class and has the
outcome of nlminb as an additional slot.
Objects can be created by calls of the form new("Goestml",
...), or with the function gogarch whereby method =
"ml" has been set.
opt:Object of class "list": List returned by
nlminb.
Z:Object of class "matrix": Transformation matrix.
U:Object of class "matrix": Orthogonal matrix.
Y:Object of class "matrix": Extracted
component matrix.
H:Object of class "list": List of conditional
variance/covariance matrices.
models:Object of class "list": List of
univariate GARCH model fits.
estby:Object of class "character": Estimation method.
X:Object of class "matrix": The data matrix.
V:Object of class "matrix": Covariance matrix
of X.
P:Object of class "matrix": Left singular
values of Var/Cov matrix of X.
Dsqr:Object of class "matrix": Square roots of
eigenvalues on diagonal, else zero.
garchf:Object of class "formula": Garch
formula used for uncorrelated component GARCH models.
name:Object of class "character": The name of
the original data object.
Class "GoGARCH", directly.
Class "Goinit", by class "GoGARCH", distance 2.
Returns the Eulerian angles.
Returns the conditional variances as object with class attribute
"mts" "ts".
Returns the conditional co-variances as object with
class attribute "mts" "ts".
Returns the conditional correlations as object with class
attribute "mts" "ts".
Returns the coeffiecients of the component GARCH models.
Returns the convergence codes of the component GARCH models.
Returns the formula for the component GARCH models.
ML-Estimation of Go-GARCH models.
Returns the value of the log-Likelihood function.
Plotting of the conditional correlations.
Returns the conditional covariances and mean
forecasts and the forecasts of the component GARCH models, object is
of class Gopredict.
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
show-method for objects of class Goestml.
summary-method for objects of class Goestml,
object is of class Gosum.
Updates an object of class Goestml.
Bernhard Pfaff
GoGARCH, Goinit,
Gosum, Gopredict,
goest-methods
This class contains the GoGARCH class and has the weights
vector and the matched orthogonal matrices as additional
slots.
Objects can be created by calls of the form new("Goestmm", ...),
or with the function gogarch whereby method = "mm" has
been set.
weights:Object of class "numeric": Weights for
aggregating the matched orthogonal matrices .
Umatched:Object of class "list": List of
matched orthogonal matrices .
Z:Object of class "matrix": Transformation matrix.
U:Object of class "matrix": Orthogonal matrix.
Y:Object of class "matrix": Extracted
component matrix.
H:Object of class "list": List of conditional
variance/covariance matrices.
models:Object of class "list": List of
univariate GARCH model fits.
estby:Object of class "character": Estimation method.
X:Object of class "matrix": The data matrix.
V:Object of class "matrix": Covariance matrix
of X.
P:Object of class "matrix": Left singular
values of Var/Cov matrix of X.
Dsqr:Object of class "matrix": Square roots of
eigenvalues on diagonal, else zero.
garchf:Object of class "formula": Garch
formula used for uncorrelated component GARCH models.
name:Object of class "character": The name of
the original data object.
Class "GoGARCH", directly.
Class "Goinit", by class "GoGARCH", distance 2.
Returns the conditional variances as object with class attribute
"mts" "ts".
Returns the conditional co-variances as object with
class attribute "mts" "ts".
Returns the conditional correlationsas object with class
attribute "mts" "ts".
Returns the coeffiecients of the component GARCH models.
Returns the convergence codes of the component GARCH models.
Returns the formula for the component GARCH models.
Methods of moments estimation of Go-GARCH models.
Plotting of the conditional correlations.
Returns the conditional covariances and mean
forecasts and the forecasts of the component GARCH models, object is
of class Gopredict.
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
show-method for objects of class Goestmm.
summary-method for objects of class Goestml,
object is of class Gosum.
Updates an object of class Goestml.
Bernhard Pfaff
Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.
GoGARCH, Goinit,
Gosum, Gopredict,
goest-methods, gogarch,
Umatch
This class contains the GoGARCH class and has the
outcome of optim as an additional slot.
Objects can be created by calls of the form new("Goestnls", ...),
or with the function gogarch whereby method = "nls" has
been set.
nls:Object of class "list": List returned by
optim.
Z:Object of class "matrix": Transformation matrix.
U:Object of class "matrix": Orthogonal matrix.
Y:Object of class "matrix": Extracted
component matrix.
H:Object of class "list": List of conditional
variance/covariance matrices.
models:Object of class "list": List of
univariate GARCH model fits.
estby:Object of class "character": Estimation method.
X:Object of class "matrix": The data matrix.
V:Object of class "matrix": Covariance matrix
of X.
P:Object of class "matrix": Left singular
values of Var/Cov matrix of X.
Dsqr:Object of class "matrix": Square roots of
eigenvalues on diagonal, else zero.
garchf:Object of class "formula": Garch
formula used for uncorrelated component GARCH models.
name:Object of class "character": The name of
the original data object.
Class "GoGARCH", directly.
Class "Goinit", by class "GoGARCH", distance 2.
Returns the conditional variances as object with class attribute
"mts" "ts".
Returns the conditional co-variances as object with
class attribute "mts" "ts".
Returns the conditional correlationsas object with class
attribute "mts" "ts".
Returns the coeffiecients of the component GARCH models.
Returns the convergence codes of the component GARCH models.
Returns the formula for the component GARCH models.
NLS-Estimation of Go-GARCH models.
Plotting of the conditional correlations.
Returns the conditional covariances and mean
forecasts and the forecasts of the component GARCH models, object
is of class Gopredict.
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
Returns the residuals of the Go-GARCH model as
object with class attribute "mts" "ts".
show-method for objects of class Goestnls.
summary-method for objects of class GoGARCH,
object is of class Gosum.
Updates an object of class GoGARCH.
Bernhard Pfaff
GoGARCH, Goinit,
Gosum, Gopredict,
goest-methods, gogarch
This function steers the specification and estimation of GO-GARCH models.
gogarch(data, formula, scale = FALSE, estby = c("ica", "mm", "ml", "nls"), lag.max = 1, initial = NULL, garchlist = list(init.rec = "mci", delta = 2, skew = 1, shape = 4, cond.dist = "norm", include.mean = FALSE, include.delta = NULL, include.skew = NULL, include.shape = NULL, leverage = NULL, trace = FALSE, algorithm = "nlminb", hessian = "ropt", control = list(), title = NULL, description = NULL), ...)gogarch(data, formula, scale = FALSE, estby = c("ica", "mm", "ml", "nls"), lag.max = 1, initial = NULL, garchlist = list(init.rec = "mci", delta = 2, skew = 1, shape = 4, cond.dist = "norm", include.mean = FALSE, include.delta = NULL, include.skew = NULL, include.shape = NULL, leverage = NULL, trace = FALSE, algorithm = "nlminb", hessian = "ropt", control = list(), title = NULL, description = NULL), ...)
data |
Matrix: the original data set. |
formula |
Formula: valid formula for univariate GARCH models. |
scale |
Logical, if |
estby |
Character: by fast ICA |
initial |
Numeric: starting values for optimization (used if
|
lag.max |
Integer: The number of used lags for computing the
matched orthogonal matrices |
garchlist |
List: Elements are passed to |
... |
Ellipsis argument: is passed to the |
The ellipsis argument is passed to the function fastICA if
estby = "ica" has been set, or to optim if estby
= "nls" is employed or to nlminb if the GO-GARCH model is
estimated by maximum likelihood, i.e., estby = "ml". It
is not employed if the methods of moments estimator is chosen.
If the argument initial is left NULL, the starting
values are computed according seq(3.0, 0.1, length.out = l),
whereby l is the length of initial for estby =
"ml" and are set to rep(0.1, d, whereby for
method = "nls". This length must be equal to for estimation by Maximum-Likelihood and for
estimation by non-linear least-Squares, whereby is the number
of columns of data.
Dependent on the chosen estimation method either an object of class
Goestica or, Goestmm or Goestml or
Goestnls is returned. All of these classes extend the
GoGARCH class.
Bernhard Pfaff
Van der Weide, Roy (2002), GO-GARCH: A Multivariate Generalized Orthogonal GARCH Model, Journal of Applied Econometrics, 17(5), 549 – 564.
Boswijk, H. Peter and van der Weide, Roy (2006), Wake me up before you GO-GARCH, Tinbergen Institute Discussion Paper, TI 2006-079/4, University of Amsterdam and Tinbergen Institute.
Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.
Broda, S.A. and Paolella, M.S. (2008): CHICAGO: A Fast and Accurate Method for Portfolio Risk Calculation, Swiss Finance Institute, Research Paper Series No. 08-08, Zuerich.
GoGARCH, Goestica,
Goestmm, Goestnls,
Goestml, goest-methods
## Not run: library(vars) ## Boswijk / van der Weide (2009) data(BVDWSTOXX) BVDWSTOXX <- zoo(x = BVDWSTOXX[, -1], order.by = BVDWSTOXX[, 1]) BVDWSTOXX <- window(BVDWSTOXX, end = as.POSIXct("2007-12-31")) BVDWSTOXX <- diff(log(BVDWSTOXX)) sectors <- BVDWSTOXX[, c("AutoParts", "Banks", "OilGas")] sectors <- apply(sectors, 2, scale, scale = FALSE) gogmm <- gogarch(sectors, formula = ~garch(1,1), estby = "mm", lag.max = 100) gogmm ## Boswijk / van der Weide (2006) data(BVDW) BVDW <- zoo(x = BVDW[, -1], order.by = BVDW[, 1]) BVDW <- diff(log(BVDW)) * 100 gognls <- gogarch(BVDW, formula = ~garch(1,1), scale = TRUE, estby = "nls") gognls ## van der Weide (2002) data(VDW) var1 <- VAR(scale(VDW), p = 1, type = "const") resid <- residuals(var1) gogml <- gogarch(resid, ~garch(1, 1), scale = TRUE, estby = "ml", control = list(iter.max = 1000)) gogml solve(gogml@Z) ## End(Not run)## Not run: library(vars) ## Boswijk / van der Weide (2009) data(BVDWSTOXX) BVDWSTOXX <- zoo(x = BVDWSTOXX[, -1], order.by = BVDWSTOXX[, 1]) BVDWSTOXX <- window(BVDWSTOXX, end = as.POSIXct("2007-12-31")) BVDWSTOXX <- diff(log(BVDWSTOXX)) sectors <- BVDWSTOXX[, c("AutoParts", "Banks", "OilGas")] sectors <- apply(sectors, 2, scale, scale = FALSE) gogmm <- gogarch(sectors, formula = ~garch(1,1), estby = "mm", lag.max = 100) gogmm ## Boswijk / van der Weide (2006) data(BVDW) BVDW <- zoo(x = BVDW[, -1], order.by = BVDW[, 1]) BVDW <- diff(log(BVDW)) * 100 gognls <- gogarch(BVDW, formula = ~garch(1,1), scale = TRUE, estby = "nls") gognls ## van der Weide (2002) data(VDW) var1 <- VAR(scale(VDW), p = 1, type = "const") resid <- residuals(var1) gogml <- gogarch(resid, ~garch(1, 1), scale = TRUE, estby = "ml", control = list(iter.max = 1000)) gogml solve(gogml@Z) ## End(Not run)
This class defines the slots for estimated GO-GARCH models. It
contains the class Goinit.
Objects can be created by calls of the form new("GoGARCH", ...).
Z:Object of class "matrix": Transformation matrix.
U:Object of class "Orthom": Orthonormal matrix.
Y:Object of class "matrix": Extracted
component matrix.
H:Object of class "list": List of conditional
variance/covariance matrices.
models:Object of class "list": List of
univariate GARCH model fits.
estby:Object of class "character": Estimation method.
CALL:Object of class "call": Result of
match.call in generating function.
X:Object of class "matrix": The data matrix.
V:Object of class "matrix": Covariance matrix
of X.
P:Object of class "matrix": Left singular
values of Var/Cov matrix of X.
Dsqr:Object of class "matrix": Square roots of
eigenvalues on diagonal, else zero.
garchf:Object of class "formula": Garch
formula used for uncorrelated component GARCH models.
name:Object of class "character": The name of
the original data object.
Class "Goinit", directly.
Returns the conditional variances as object with class attribute
"mts" "ts".
Returns the conditional co-variances as object with
class attribute "mts" "ts".
Returns the conditional correlationsas object with class
attribute "mts" "ts".
Returns the coeffiecients of the component GARCH models.
Returns the convergence codes of the component GARCH models.
Returns the formula for the component GARCH models.
Plotting of the conditional correlations.
Returns the conditional covariances and mean
forecasts and the forecasts of the component GARCH models, object is
of class Gopredict.
Returns the residuals of the GO-GARCH model.
show-method for objects of class GoGARCH.
summary-method for objects of class GoGARCH,
object is of class Gosum.
Updates an object of class GoGARCH.
Bernhard Pfaff
This function can be utilized to create objects of class
Goinit. These objects are the starting point for estimating
GO-GARCH models.
goinit(X, garchf = ~garch(1, 1), scale = FALSE)goinit(X, garchf = ~garch(1, 1), scale = FALSE)
X |
Matrix: the data matrix. |
garchf |
Formula: A formula object that will be used in the GARCH models of the uncorrelated components. |
scale |
Logical, if |
This function computes the variance/covariance matrix of
X. Next the singular value decomposition is applied and the
projection matrix as well as the diagonal matrix with the square roots
of the eigen values are computed.
An object of class Goinit.
Bernhard Pfaff
## Not run: library(vars) data(VDW) var1 <- VAR(VDW, p = 1, type = "const") resid <- resid(var1) goinit(resid, scale = TRUE) ## End(Not run)## Not run: library(vars) data(VDW) var1 <- VAR(VDW, p = 1, type = "const") resid <- resid(var1) goinit(resid, scale = TRUE) ## End(Not run)
This class defines the required slots for estimating GO-GARCH models.
Objects can be created by calls of the form new("Goinit", ...),
or more conveniently by goinit().
X:Object of class "matrix": The data matrix.
V:Object of class "matrix": Covariance matrix
of X.
P:Object of class "matrix": Left singular
values of Var/Cov matrix of X.
Dsqr:Object of class "matrix": Square roots of
eigenvalues on diagonal, else zero.
garchf:Object of class "formula": Garch
formula used for uncorrelated component GARCH models.
name:Object of class "character": The name of
the original data object.
Prints the slots, whereby for X only the head is
displayed.
Bernhard Pfaff
showClass("Goinit")showClass("Goinit")
This function returns the negative of the log-Likelihood function for GO-GARCH models.
gollh(params, object, garchlist)gollh(params, object, garchlist)
params |
Vector of initial values for |
object |
An object of class |
garchlist |
List, elements are passed to |
The log-Likelihood function of GO-GARCH models is given as:
whereby , and
is the conditional variance matrix of the independent
components.
negll |
Scalar, the negative value of the log-Likelihood function. |
Bernhard Pfaff
Van der Weide, Roy (2002), GO-GARCH: A Multivariate Generalized Orthogonal GARCH Model, Journal of Applied Econometrics, 17(5), 549 – 564.
This is the target function for estimating the matrix by
non-linear least-squares. It is used in the estimation method
goest if method = "nls" is chosen.
gonls(params, SSI)gonls(params, SSI)
params |
The initial values of the |
SSI |
A list with two elements, each a list itself, containing
|
Boswijk and van der Weiden (2006) proposed the following criterion function:
for retrieving the matrix . This matrix is the eigen vector
matrix of . The linear map and its
inverse can then be computed for calculating the component matrix
.
f |
|
Bernhard Pfaff
Boswijk, H. Peter and van der Weide, Roy (2006), Wake me up before you GO-GARCH, Tinbergen Institute Discussion Paper, TI 2006-079/4, University of Amsterdam and Tinbergen Institute.
This class defines the slots for forecasts from a GO-GARCH model.
Objects can be created by calls of the form new("Gopredict",
...), or with the method predict of formal class objects
GoGARCH and Goestml.
Hf:Object of class "list": The forecasted
conditional covariances.
Xf:Object of class "matrix": The transformed
forecasts of the component GARCH mean models.
CGARCHF:Object of class "list": The original
forecasts of the component GARCH models.
Returns the forecasted conditional correlations.
Returns the forecasted conditional co-variances.
Returns the forecasted conditional variances.
show-method for objects of class Gopredict.
In case more than 10 forecasts steps are computed, the
show-method displays only the head of the returned
objects. Furthermore, the show-method displays the forecasted
conditional variances only. The forecasted conditional co-variances
and/or the forecasted conditional correlations can be retrieved with
the methods ccov or ccor, respectively.
Bernhard Pfaff
The formal summary class of GoGARCH objects or objects that
extend this class.
Objects can be created by calls of the form new("Gosum", ...)
or are set by the summary-method.
name:character: the name of the original data object.
method:character: the estimation method.
model:formula: The GARCH model formula for the
component GARCH models.
garchc:list: The elements are matcoef matrices
generated by garchFit for the components.
Zinv:matrix: The inverse of the linear map .
show-method for objects of class Gosum.
Bernhard Pfaff
This function returns an object of class GoGARCH based on an
input vector of Euler angles.
gotheta(theta, object, garchlist = list(init.rec = "mci", delta = 2, skew = 1, shape = 4, cond.dist = "norm", include.mean = FALSE, include.delta = NULL, include.skew = NULL, include.shape = NULL, leverage = NULL, trace = FALSE, algorithm = "nlminb", hessian = "ropt", control = list(), title = NULL, description = NULL))gotheta(theta, object, garchlist = list(init.rec = "mci", delta = 2, skew = 1, shape = 4, cond.dist = "norm", include.mean = FALSE, include.delta = NULL, include.skew = NULL, include.shape = NULL, leverage = NULL, trace = FALSE, algorithm = "nlminb", hessian = "ropt", control = list(), title = NULL, description = NULL))
theta |
Vector of Euler angles. |
object |
An object of formal class |
garchlist |
List with optional elements passed to |
In a first step the orthogonal matrix is computed as the
product of rotation matrices given the vector theta of Euler
angles with the function UprodR. The linear map is
computed next as . The unobserved
components are calculated as . These are
then utilized in the estimation of the univariate GARCH models
according to object@garchf. The conditional variance/covariance
matrices are calculated according to whereby
signifies a matrix with the conditional variances of the
unvariate GARCH models on its diagonal.
Returns an object of class GoGARCH.
Bernhard Pfaff
Van der Weide, Roy (2002), GO-GARCH: A Multivariate Generalized Orthogonal GARCH Model, Journal of Applied Econometrics, 17(5), 549 – 564.
Goinit, GoGARCH,
Goestml, garchFit
## Not run: library(vars) data(VDW) var1 <- VAR(VDW, p = 1, type = "const") resid <- resid(var1) gin <- goinit(resid, scale = TRUE) gotheta(0.5, gin) ## End(Not run)## Not run: library(vars) data(VDW) var1 <- VAR(VDW, p = 1, type = "const") resid <- resid(var1) gin <- goinit(resid, scale = TRUE) gotheta(0.5, gin) ## End(Not run)
This class defines an orthogonal matrix, which is characterized by
and .
Objects can be created by calls of the form new("Orthom",
...). In addition the function UprodR returns an object of
formal class Orthom.
M:Object of class "matrix".
Returns the slot M of class Orthom.
print-method for objects of class Orthom.
show-method for objects of class Orthom.
Transpose of object@M.
Objects are validated by validOrthomObject(). This function
is utilised by validObject().
Bernhard Pfaff
showClass("Orthom")showClass("Orthom")
Given an angle whereby the
function Rd2 returns a 2-dimensional rotation matrix of Euler angles.
Rd2(theta)Rd2(theta)
theta |
Numeric, angle in the interval |
R |
A 2-dimensional rotation matrix. |
Bernhard Pfaff
Rd2(pi/3)Rd2(pi/3)
This function matches an orthogonal matrix to the importance of the columns of the matrix to which it should be matched.
Umatch(from, to)Umatch(from, to)
from |
Matrix: orthogonal |
to |
Matrix: orthogonal |
mat |
Matched matrix. |
Bernhard Pfaff
Boswijk, H. Peter and van der Weide, Roy (2009), Method of Moments Estimation of GO-GARCH Models, Working Paper, University of Amsterdam, Tinbergen Institute and World Bank.
Liebeck, H. and Osborne, A. (1991), The Generation of All Rational Orthogonal Matrices, The American Mathematical Monthly, 98 (2) (Feb. 1991), 131 – 133.
This function returns the symmetric matrix from a vector that
resulted from .
unvech(v)unvech(v)
v |
Vector, numeric. |
The vector v must have length equal to ,
whereby is a dimension of the symmetric matrix .
X |
Matrix, symmetric of order |
Bernhard Pfaff
v <- c(1, 2, 3, 4, 5, 6) unvech(v)v <- c(1, 2, 3, 4, 5, 6) unvech(v)
This function returns an orthogonal matrix which results of the matrix products of rotation matrices.
UprodR(theta)UprodR(theta)
theta |
Vector, of angles of the rotation matrices. |
The length of theta must be equal to ,
where is the dimension of the orthogonal matrix. The elements
of theta must lie in the interval .
result |
Object of class |
Bernhard Pfaff
Vilenkin, N. Ja. (1968), Special Functions and the Theory of Group Representations, Translations of Mathematical Monographs, 22, American Math. Soc., Providence, Rhode Island, USA.
theta <- c(pi/3, pi/5, pi/7) U <- UprodR(theta) Utheta <- c(pi/3, pi/5, pi/7) U <- UprodR(theta) U
This function validates objects of class Goinit.
validGoinitObject(object)validGoinitObject(object)
object |
Object of class |
This function is utilized by validObject(). It is tested
whether object@V, object@P, object@Dsqr are
square matrices; object@V coincides with the singular value
decomposition.
TRUE |
Logical, |
Bernhard Pfaff
data(VDW) go <- goinit(VDW) validObject(go)data(VDW) go <- goinit(VDW) validObject(go)
This function validates objects of class Orthom.
validOrthomObject(object)validOrthomObject(object)
object |
Object of class |
This function is utilized by validObject(). It is tested
whether object@M is a square matrix, has and
.
TRUE |
Logical, |
Bernhard Pfaff
theta <- c(pi/3, pi/5, pi/7) U <- UprodR(theta) validObject(U)theta <- c(pi/3, pi/5, pi/7) U <- UprodR(theta) validObject(U)
The daily (log) returns of the Dow Jones Industrial Average and the NASDAQ composite, respectively. The daily observations start at the first of January, 1990, and end in October 2001.
data(VDW)data(VDW)
A data frame with 3082 observations on the following 2 variables.
DJIALog-return of Dow Jones Industrial Average.
NASDAQLog-return of NASDAQ.
This data set has been utilized in the source below and can be downloaded from the web-site of the Journal of Applied Econometrics (see link below).
Van der Weide, Roy (2002), GO-GARCH: A Multivariate Generalized Orthogonal GARCH Model, Journal of Applied Econometrics, 17(5), 549 – 564.
http://qed.econ.queensu.ca/jae/2002-v17.5/van_der_weide/
data(VDW) str(VDW)data(VDW) str(VDW)